@@ -24,6 +24,9 @@ import warnings
 warnings.filterwarnings(action='ignore')
 import shutil
 from pytorch_lightning.callbacks import RichProgressBar, TQDMProgressBar
+import logging
+logger = logging.getLogger()
+logger.setLevel(logging.INFO)
 
 class BaseExperiment:
     r"""Parent class of ``Experiment``.
@@ -213,7 +216,7 @@ class BaseExperiment:
 
     def update_log_path(self)->None:
         r"""Updates log path"""
-        self.exp_path = self.project_path + "/"+ self.fit_or_cv + "/" + "random_state-{}".format(self.random_state)
+        self.exp_path = self.project_path + "/"+ self.fit_or_cv + "/" + f"random_state-{self.random_state}"
         self.log_path = self.exp_path + "/logs"
 
     def update_exp_metadata(self)->None:
@@ -492,13 +495,10 @@ class BaseExperiment:
     )->"BaseEstimator":
         # for consistency with the logging style of pytorch_lightning.
         self.update_log_path()
-        folder_dir = self.log_path + "/tensorboardlogs/" + self.model.__class__.__name__ 
+        folder_dir = f"{self.log_path}/tensorboardlogs/{self.model.__class__.__name__}/{self.model_metadata}"
         self._create_folder(folder_dir)
-        try:
-            version = os.listdir(folder_dir) 
-        except: # when there is no such directory made
-            version = 0
-        log_dir = folder_dir + "/" + self.model_metadata + "/" + "version_{}".format(version)
+        version = os.listdir(folder_dir)
+        log_dir = f"{folder_dir}/version_{version}"
         self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
         self.model.fit(self.X_train, self.y_train, sample_weight)
@@ -626,18 +626,26 @@ class BaseExperiment:
             raise NotImplementedError("Astrape only supports variants of sklearn and pl.LightningModule.")
         checkpoint_path = self.log_path + "/checkpoints/" + model.__class__.__name__ + "/" + model_metadata
         self._create_folder(checkpoint_path)
-        ckpt_path = checkpoint_path +"/" + ckpt_name 
+        ckpt_version = len(os.listdir(checkpoint_path))
+        ckpt_path = checkpoint_path +"/" + ckpt_name + f"version_{ckpt_version}"
         
         if isinstance(model, BaseEstimator):
             pickle.dump(model, open(ckpt_path, 'wb'))
         elif isinstance(model, pl.LightningModule):
             trainer.save_checkpoint(ckpt_path)
 
+
         metadata_dir = self.log_path + "/jsonlogs/" + model.__class__.__name__ + "/" + model_metadata
         self._create_folder(metadata_dir)
-        version = len(os.listdir(metadata_dir))
-        self._create_folder(metadata_dir+"/version_{}".format(version))
-        tensorboard_logdir = self.logger.experiment.get_logdir()
+        jsonlog_version = len(os.listdir(metadata_dir))
+        
+        
+        self._create_folder(metadata_dir+f"/version_{jsonlog_version}")
+        if isinstance(model, BaseEstimator):
+            tensorboard_logdir = self.logger.get_logdir()
+        else:
+            tensorboard_logdir = self.logger.experiment.get_logdir()
+
         if model.__class__ in self.saved_model_types:
             self.saved_model_types.update({model.__class__: self.saved_model_types[model.__class__] + 1})
         else:
@@ -759,7 +767,7 @@ class BaseExperiment:
 
         for key, value in success.items():
             if value == 0:
-                print("There is no directory {}".format(key))
+                logger.info(f"There is no directory {key}")
             
     def best_ckpt_thus_far(
         self, 
@@ -785,7 +793,7 @@ class BaseExperiment:
         try:
             jsonlogdir = self.log_path + "/jsonlogs"
         except:
-            print("Nothing has been saved yet.")
+            logger.info("Nothing has been saved yet.")
             return None
         if not mode:
             if val_metric == 'val/loss':
@@ -835,7 +843,7 @@ class BaseExperiment:
                     ckpt_dir = ckpt
                     ckpt_extension_type = extension_type
             if ckpt_extension_type not in extension_candidates:
-                raise ValueError("Wrong file extension {} for the checkpoint. It should be in {}".format(ckpt_extension_type, extension_candidates))
+                raise ValueError(f"Wrong file extension {ckpt_extension_type} for the checkpoint. It should be in {extension_candidates}")
             if ckpt_extension_type == ".sav":
                 best_ckpt = pickle.load(open(ckpt_dir, 'rb'))
             elif BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type):
@@ -872,9 +880,9 @@ class BaseExperiment:
             :obj:`LightningModule` or :obj:`BaseEstimator` or None: Returns the best checkpoint as per the validation metric. Returns None if there are no saved checkpoints.  
         """
         if val_metric not in ["val/loss", "val/acc", "val/auc"]:
-            raise ValueError("Wrong type of val_metric. It should be one of [{}]".format(*["val/loss", "val/acc", "val/auc"]))
+            raise ValueError(f"Wrong type of val_metric. It should be one of 'val/loss', 'val/acc', 'val/auc'")
         if len(self.stack) == 0:
-            print("Nothing is stored in stack.")
+            logger.info("Nothing is stored in stack.")
             return None
         best_val_score = None
         best_idx = None
@@ -953,7 +961,8 @@ class BaseExperiment:
             
             new_metadata = model.__class__.__name__ + truncated_hparams_str   
             if len(new_metadata) > length_limit:
-                print("The length of the metadata is too long due to long hyperparameter specs. We will take the first {} letters from the hyperparameter part.".format(length_limit-subtract))
+                logger.info(f"The length of the metadata is too long due to long hyperparameter specs. \
+                    We will take the first {length_limit-subtract} letters from the hyperparameter part.")
                 new_metadata = hparams_str[:length_limit-subtract] 
 
                 model_metadata = new_metadata
@@ -996,10 +1005,11 @@ class BaseExperiment:
         log = {'model_type' : model.__class__.__name__}
         error_count = 0
         self.update_log_path()
+
         model_metadata = self.set_model_metadata(model, self.get_hparams(model))
-        metadata_dir_ = self.log_path+'/jsonlogs/'+ model.__class__.__name__ + "/" + model_metadata
-        jsonlog_dir = metadata_dir_ + "/" + 'version_{}'.format(version)
-        json_logdir = jsonlog_dir + "/validation_metrics.json"
+        jsonlog_folder = f"{self.log_path}/jsonlogs/{model.__class__.__name__}/{model_metadata}/version_{version}"
+        self._create_folder(jsonlog_folder) # necessary for sklearn-based models
+        jsonlog_path = f"{jsonlog_folder}/validation_metrics.json"
 
         if not metrics_dict:
             event = EventAccumulator(tensorboard_logdir)
@@ -1063,7 +1073,7 @@ class BaseExperiment:
         if error_count == 6:
             raise AssertionError("Nothing has been logged.")
         
-        with open(json_logdir, 'w') as fout:
+        with open(jsonlog_path, 'w') as fout:
             json.dump(log, fout)
 
 
